@@ -1,5 +1,14 @@
+tps_sejour <-
+function(x,s=.0){
+	w = which(x<s)
+	dw = c(2,diff(w),2)
+    wdw=which(dw>1)
+    dur = diff(wdw)
+    return(dur)	
+}
+
 MeanDurUnder <-
-function(data,data.sim,u,alpha=.05,col="red"){
+function(data,data.sim,u,alpha=.05,col="red",plot=TRUE){
 N.samples = dim(data)[2]
 Bsim =  dim(data.sim)[2]/N.samples
 tps.data = NULL
@@ -7,7 +16,7 @@ tps.hh = NULL
 F = NULL
 Fhh = NULL
 for (k in 1:length(u))
-{	F[k] = sum(data<u[k])
+{	F[k] = sum(data<u[k],na.rm=TRUE)
 	tps.data[k] = mean(tps_sejour(data,s=u[k]))
 	Fhh[k] = sum(data.sim<u[k])
 	tps.hh[k] = mean(tps_sejour(data.sim,s=u[k]) )
@@ -30,16 +39,20 @@ for (k in 1:length(u)) {
 	ICsup.hh[k] = quantile(q.tps.hh[,k],1-alpha/2)
 }
 
-tps.hh= apply(q.tps.hh,2,mean)
+tps.hh = apply(q.tps.hh,2,mean)
 
-plot(F,tps.data,typ="l",ylim=range(c(tps.data,tps.hh)),log="y",xlab = "P(Y<u)",lwd=3,ylab="Mean sojourn duration under u  (log scale)")
-lines(Fhh,tps.hh,col=col)
-lines(Fhh,ICinf.hh,col=col,lty=2)
-lines(Fhh,ICsup.hh,col=col,lty=2)
 CI = matrix(0,length(u),2)
 CI[,1] = ICinf.hh
 CI[,2] = ICsup.hh
-return(list(F=F,mdu.data = tps.data,F.sim=Fhh,mdu.sim = tps.hh,CI=CI,mdu.sim.all=q.tps.hh))
+
+
+if (plot) {
+	plot(F,tps.data,typ="l",ylim=range(c(tps.data,tps.hh)),log="y",xlab = "P(Y<u)",lwd=3,ylab="Mean sojourn duration under u  (log scale)")
+	lines(Fhh,tps.hh,col=col)
+	lines(Fhh,ICinf.hh,col=col,lty=2)
+	lines(Fhh,ICsup.hh,col=col,lty=2)
+}
+return(list(F=F,mdu.data = tps.data,F.sim=Fhh,mdu.sim = q.tps.hh,CI=CI,mdu.sim.all=q.tps.hh))
 
 
 
